@@ -6,8 +6,8 @@ int main(int argc, char *argv[])
     QCoreApplication a(argc, argv);
     a.setOrganizationName("callerx");
     a.setApplicationName("callerx");
-    CallerXDaemon* daemon = new CallerXDaemon();
-    QObject::connect(daemon, SIGNAL(quit()), &a, SLOT(quit()));
-    daemon->Start();
+    CallerXDaemon* b = new CallerXDaemon();
+    QObject::connect(b, SIGNAL(quit()), &a, SLOT(quit()));
+    b->Start();
     return a.exec();
 }
